@@ -22,13 +22,14 @@ class TimerScheduler(threading.Thread):
     The base class to schedule Task which will be executed after some time
     """
 
-    def __init__(self, num_threads, logger=None):
-        super(TimerScheduler, self).__init__()
+    def __init__(self, num_threads, name=None, logger=None):
+        super(TimerScheduler, self).__init__(name=name)
         self.num_threads = int(num_threads)
         if self.num_threads < 1:
             self.num_threads = 1
         self.graceful_stop = threading.Event()
-        self.executors = futures.ThreadPoolExecutor(max_workers=self.num_threads)
+        self.executors = futures.ThreadPoolExecutor(max_workers=self.num_threads,
+                                                    thread_name_prefix=name)
 
         self._task_queue = []
         self._lock = threading.RLock()
@@ -90,3 +91,11 @@ class TimerScheduler(threading.Thread):
                 self.executors.submit(self.execute_task, task)
         except Exception as error:
             self.logger.critical("Caught an exception: %s\n%s" % (str(error), traceback.format_exc()))
+
+    def execute_timer_schedule(self):
+        try:
+            task = self.get_ready_task()
+            if task:
+                self.executors.submit(self.execute_task, task)
+        except Exception as error:
+            self.logger.critical("Caught an exception: %s\n%s" % (str(error), traceback.format_exc()))
